summaryrefslogtreecommitdiffstats
path: root/lib/widgets/processwidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/widgets/processwidget.cpp')
-rw-r--r--lib/widgets/processwidget.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/lib/widgets/processwidget.cpp b/lib/widgets/processwidget.cpp
index a49a1078..66796266 100644
--- a/lib/widgets/processwidget.cpp
+++ b/lib/widgets/processwidget.cpp
@@ -33,9 +33,9 @@ ProcessListBoxItem::ProcessListBoxItem(const TQString &s, Type type)
: TQListBoxText(s), t(type)
{
TQString clean = s;
- clean.replace( TQChar('\t'), TQString(" ") );
- clean.replace( TQChar('\n'), TQString() );
- clean.replace( TQChar('\r'), TQString() );
+ clean.tqreplace( TQChar('\t'), TQString(" ") );
+ clean.tqreplace( TQChar('\n'), TQString() );
+ clean.tqreplace( TQChar('\r'), TQString() );
setText( clean );
setCustomHighlighting(true);
@@ -66,14 +66,14 @@ TQColor ProcessListBoxItem::blend(const TQColor &c1, const TQColor &c2, double k
int g = normalize((int)blend1((double)c1.green(), (double)c2.green(), k));
int b = normalize((int)blend1((double)c1.blue(), (double)c2.blue(), k));
- return TQColor(qRgb(r, g, b));
+ return TQColor(tqRgb(r, g, b));
}
void ProcessListBoxItem::paint(TQPainter *p)
{
TQColor dim, warn, err, back;
if (listBox()) {
- const TQColorGroup& group = listBox()->palette().active();
+ const TQColorGroup& group = listBox()->tqpalette().active();
if (isSelected()) {
back = group.button();
warn = group.buttonText();
@@ -88,13 +88,13 @@ void ProcessListBoxItem::paint(TQPainter *p)
}
else
{
- warn = Qt::black;
- dim = Qt::darkBlue;
- err = Qt::darkRed;
+ warn = TQt::black;
+ dim = TQt::darkBlue;
+ err = TQt::darkRed;
if (isSelected())
- back = Qt::lightGray;
+ back = TQt::lightGray;
else
- back = Qt::white;
+ back = TQt::white;
}
p->fillRect(p->window(), TQBrush(back));
p->setPen((t==Error)? err :
@@ -103,10 +103,10 @@ void ProcessListBoxItem::paint(TQPainter *p)
}
-ProcessWidget::ProcessWidget(TQWidget *parent, const char *name)
- : KListBox(parent, name)
+ProcessWidget::ProcessWidget(TQWidget *tqparent, const char *name)
+ : KListBox(tqparent, name)
{
- setFocusPolicy(TQWidget::NoFocus);
+ setFocusPolicy(TQ_NoFocus);
// Don't override the palette, as that can mess up styles. Instead, draw
// the background ourselves (see ProcessListBoxItem::paint).
@@ -227,7 +227,7 @@ void ProcessWidget::childFinished(bool normal, int status)
if (normal) {
if (status) {
- s = i18n("*** Exited with status: %1 ***").arg(status);
+ s = i18n("*** Exited with status: %1 ***").tqarg(status);
t = ProcessListBoxItem::Error;
} else {
s = i18n("*** Exited normally ***");
@@ -249,12 +249,12 @@ void ProcessWidget::childFinished(bool normal, int status)
}
-TQSize ProcessWidget::minimumSizeHint() const
+TQSize ProcessWidget::tqminimumSizeHint() const
{
// I'm not sure about this, but when I don't use override minimumSizeHint(),
// the initial size in clearly too small
- return TQSize( TQListBox::sizeHint().width(),
+ return TQSize( TQListBox::tqsizeHint().width(),
(fontMetrics().lineSpacing()+2)*4 );
}
@@ -249,12 +249,12 @@ void ProcessWidget::childFinished(bool normal, int status)
{
- // I'm not sure about this, but when I don't use override minimumSizeHint(),
+ // I'm not sure about this, but when I don't use override tqminimumSizeHint(),
// the initial size in clearly too small